@@ -15,6 +15,8 @@ namespace rudiments {
 
 class listener;
 
+class filedescriptorprivate;
+
 class filedescriptor {
 	public:
 			filedescriptor();
@@ -109,13 +111,17 @@ class filedescriptor {
 		// Write methods - write data to the file descriptor.
 		// These methods return the number of bytes that were
 		// successfully written or RESULT_ERROR if an error occurred.
-		ssize_t	write(unsigned short number) const;
+		ssize_t	write(uint16_t number) const;
 				// Write "number" to the file descriptor.
-		ssize_t	write(unsigned long number) const;
+		ssize_t	write(uint32_t number) const;
 				// Write "number" to the file descriptor.
-		ssize_t	write(short number) const;
+		ssize_t	write(uint64_t number) const;
 				// Write "number" to the file descriptor.
-		ssize_t	write(long number) const;
+		ssize_t	write(int16_t number) const;
+				// Write "number" to the file descriptor.
+		ssize_t	write(int32_t number) const;
+				// Write "number" to the file descriptor.
+		ssize_t	write(int64_t number) const;
 				// Write "number" to the file descriptor.
 		ssize_t	write(float number) const;
 				// Write "number" to the file descriptor.
@@ -153,13 +159,17 @@ class filedescriptor {
 		// These methods return the number of bytes that were
 		// successfully written, RESULT_ERROR if an error occurred or
 		// RESULT_TIMEOUT if a timeout occurred.
-		ssize_t	write(unsigned short number, long sec, long usec) const;
+		ssize_t	write(uint16_t number, long sec, long usec) const;
 				// Write "number" to the file descriptor.
-		ssize_t	write(unsigned long number, long sec, long usec) const;
+		ssize_t	write(uint32_t number, long sec, long usec) const;
 				// Write "number" to the file descriptor.
-		ssize_t	write(short number, long sec, long usec) const;
+		ssize_t	write(uint64_t number, long sec, long usec) const;
 				// Write "number" to the file descriptor.
-		ssize_t	write(long number, long sec, long usec) const;
+		ssize_t	write(int16_t number, long sec, long usec) const;
+				// Write "number" to the file descriptor.
+		ssize_t	write(int32_t number, long sec, long usec) const;
+				// Write "number" to the file descriptor.
+		ssize_t	write(int64_t number, long sec, long usec) const;
 				// Write "number" to the file descriptor.
 		ssize_t	write(float number, long sec, long usec) const;
 				// Write "number" to the file descriptor.
@@ -173,26 +183,27 @@ class filedescriptor {
 		ssize_t	write(bool value, long sec, long usec) const;
 				// Write "value" to the file descriptor.
 		ssize_t	write(const unsigned char *string,
-						long sec, long usec) const;
+					long sec, long usec) const;
 				// Write "string" to the file descriptor.  Note
 				// that "string" must be NULL-terminated.
-		ssize_t	write(const char *string, long sec, long usec) const;
+		ssize_t	write(const char *string,
+					long sec, long usec) const;
 				// Write "string" to the file descriptor.  Note
 				// that "string" must be NULL-terminated.
 		ssize_t	write(const unsigned char *string, size_t size,
-						long sec, long usec) const;
+					long sec, long usec) const;
 				// Write "size" bytes from "string" to the file
 				// descriptor.  Note that it is possible to
 				// write beyond the string's NULL terminator
 				// using this method.
 		ssize_t	write(const char *string, size_t size,
-						long sec, long usec) const;
+					long sec, long usec) const;
 				// Write "size" bytes from "string" to the file
 				// descriptor.  Note that it is possible to
 				// write beyond the string's NULL terminator
 				// using this method.
 		ssize_t	write(const void *buffer, size_t size,
-						long sec, long usec) const;
+					long sec, long usec) const;
 				// Write "size" bytes from "buffer" to the file
 				// descriptor.
 
@@ -200,17 +211,23 @@ class filedescriptor {
 		// Read methods - read data from the file descriptor.
 		// These methods return the number of bytes that were
 		// successfully read or RESULT_ERROR if an error occurred.
-		ssize_t	read(unsigned short *buffer) const;
-				// Reads sizeof(unsigned short) bytes
+		ssize_t	read(uint16_t *buffer) const;
+				// Reads sizeof(uint16_t) bytes
 				// from the file descriptor into "buffer".
-		ssize_t	read(unsigned long *buffer) const;
-				// Reads sizeof(unsigned long) bytes
+		ssize_t	read(uint32_t *buffer) const;
+				// Reads sizeof(uint32_t) bytes
 				// from the file descriptor into "buffer".
-		ssize_t	read(short *buffer) const;
-				// Reads sizeof(short) bytes
+		ssize_t	read(uint64_t *buffer) const;
+				// Reads sizeof(uint64_t) bytes
 				// from the file descriptor into "buffer".
-		ssize_t	read(long *buffer) const;
-				// Reads sizeof(long) bytes
+		ssize_t	read(int16_t *buffer) const;
+				// Reads sizeof(int16_t) bytes
+				// from the file descriptor into "buffer".
+		ssize_t	read(int32_t *buffer) const;
+				// Reads sizeof(int32_t) bytes
+				// from the file descriptor into "buffer".
+		ssize_t	read(int64_t *buffer) const;
+				// Reads sizeof(int64_t) bytes
 				// from the file descriptor into "buffer".
 		ssize_t	read(float *buffer) const;
 				// Reads sizeof(float) bytes from the file
@@ -248,17 +265,23 @@ class filedescriptor {
 		// These methods return the number of bytes that were
 		// successfully read, RESULT_ERROR if an error occurred or
 		// RESULT_TIMEOUT if a timeout occurred.
-		ssize_t	read(unsigned short *buffer, long sec, long usec) const;
-				// Reads sizeof(unsigned short) bytes
+		ssize_t	read(uint16_t *buffer, long sec, long usec) const;
+				// Reads sizeof(uint16_t) bytes
 				// from the file descriptor into "buffer".
-		ssize_t	read(unsigned long *buffer, long sec, long usec) const;
-				// Reads sizeof(unsigned long) bytes
+		ssize_t	read(uint32_t *buffer, long sec, long usec) const;
+				// Reads sizeof(uint32_t) bytes
 				// from the file descriptor into "buffer".
-		ssize_t	read(short *buffer, long sec, long usec) const;
-				// Reads sizeof(short) bytes
+		ssize_t	read(uint64_t *buffer, long sec, long usec) const;
+				// Reads sizeof(uint64_t) bytes
 				// from the file descriptor into "buffer".
-		ssize_t	read(long *buffer, long sec, long usec) const;
-				// Reads sizeof(long) bytes
+		ssize_t	read(int16_t *buffer, long sec, long usec) const;
+				// Reads sizeof(int16_t) bytes
+				// from the file descriptor into "buffer".
+		ssize_t	read(int32_t *buffer, long sec, long usec) const;
+				// Reads sizeof(int32_t) bytes
+				// from the file descriptor into "buffer".
+		ssize_t	read(int64_t *buffer, long sec, long usec) const;
+				// Reads sizeof(int64_t) bytes
 				// from the file descriptor into "buffer".
 		ssize_t	read(float *buffer, long sec, long usec) const;
 				// Reads sizeof(float) bytes from the file
@@ -266,7 +289,8 @@ class filedescriptor {
 		ssize_t	read(double *buffer, long sec, long usec) const;
 				// Reads sizeof(double) bytes from the file
 				// descriptor into "buffer".
-		ssize_t	read(unsigned char *buffer, long sec, long usec) const;
+		ssize_t	read(unsigned char *buffer,
+					long sec, long usec) const;
 				// Reads sizeof(unsigned char) bytes
 				// from the file descriptor into "buffer".
 		ssize_t	read(char *buffer, long sec, long usec) const;
@@ -276,19 +300,19 @@ class filedescriptor {
 				// Reads sizeof(bool) bytes from the
 				// file descriptor into "buffer".
 		ssize_t	read(unsigned char *buffer, size_t size,
-						long sec, long usec) const;
+					long sec, long usec) const;
 				// Reads "size" bytes from the file descriptor
 				// into "buffer".
 		ssize_t	read(char *buffer, size_t size,
-						long sec, long usec) const;
+					long sec, long usec) const;
 				// Reads "size" bytes from the file descriptor
 				// into "buffer".
 		ssize_t	read(void *buf, size_t size,
-						long sec, long usec) const;
+					long sec, long usec) const;
 				// Reads "size" bytes from the file descriptor
 				// into "buffer".
 		ssize_t	read(char **buffer, char *terminator,
-						long sec, long usec) const;
+					long sec, long usec) const;
 				// Reads from the file desciptor into "buffer"
 				// until "terminator" is encountered.  Note
 				// that "buffer" is allocated internally and
@@ -399,6 +423,22 @@ class filedescriptor {
 			// number of bytes from the file descriptor, in several
 			// passes if necessary.
 
+		// By default, write() will attempt to write the specified
+		// number of bytes from the file descriptor, in several passes
+		// if necessary.  No single pass will try to read more than
+		// SSIZE_MAX bytes.  These methods override that behavior.
+		void	allowShortWrites();
+			// Causes a write to return the number of bytes that
+			// were written in a single pass from the file
+			// descriptor.  Note that writes longer than SSIZE_MAX
+			// will always return SSIZE_MAX or fewer bytes.  This
+			// is useful, for example, when writing to devices
+			// which block rather than returning 0 for EOF.
+		void	dontAllowShortWrites();
+			// Causes a write to attempt to write the specified
+			// number of bytes from the file descriptor, in several
+			// passes if necessary.
+
 
 		// By default, calls to waitForNonBlockingRead() and
 		// waitForNonBlockingWrite() will wait using the select()
@@ -434,19 +474,24 @@ class filedescriptor {
 			// Interfaces for performing varions miscellaneous
 			// operations on the file descriptor.
 
-		bool	bufferWrites();
+		bool	useNaglesAlgorithm();
 			// Causes small write()'s to be collected up and
 			// sent together when the buffer is full or when
 			// a maximum of 0.2 seconds has gone by.  This is
 			// the default. (enables Nagle's algorithm)
 			//
 			// Returns true on success and false on failure.
-		bool	dontBufferWrites();
+		bool	dontUseNaglesAlgorithm();
 			// Causes all write()'s to be sent immediately.
 			// (disables Nagle's algorithm)
 			//
 			// Returns true on success and false on failure.
 
+		bool	getTcpWriteBufferSize(int *size);
+		bool	setTcpWriteBufferSize(int size);
+		bool	getTcpReadBufferSize(int *size);
+		bool	setTcpReadBufferSize(int size);
+
 		const char	*getType() const;
 
 		char		*getPeerAddress() const;
