@@ -1,4 +1,4 @@
 // Copyright (c) 2004 David Muse
 // See the COPYING file for more information
 
-#include <rudiments/private/config.h>
+#include <rudiments/private/inttypes.h>
