@@ -2,11 +2,6 @@
 // See the COPYING file for more information.
 
 	private:
-		xmldom	xmld;
-		xmldom	xmldtd;
-
-		stringbuffer	err;
-
 		bool	parseDtd();
 		bool	newElement(xmldomnode *node);
 		bool	parseList(const char *attributelist,
@@ -19,3 +14,5 @@
 
 			dtd(const dtd &d);
 		dtd	&operator=(const dtd &d);
+
+		dtdprivate	*pvt;
