@@ -1,7 +1,7 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/private/config.h>
+#include <rudiments/private/inttypes.h>
 
 #include <netdb.h>
 #include <sys/types.h>
