@@ -1,7 +1,7 @@
 // Copyright (c) 2004 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/private/config.h>
+#include <rudiments/private/inttypes.h>
 #include <rudiments/private/rudimentsinlines.h>
 
 #include <termios.h>
