@@ -2,5 +2,7 @@
 // See the COPYING file for more information.
 
 	protected:
-		const char	*filename;
-		sockaddr_un	sockaddrun;
+		const char	*_filename();
+		sockaddr_un	*_sun();
+	private:
+		unixsocketutilprivate	*pvt;
